Learn R Programming

iconr (version 0.1.0)

contemp_nds: Select Contemporaneous Nodes

Description

Find the connected component, or subgraph, of contemporaneous nodes (connected by normal and attribute edges) given a selected node and remove the other components

Usage

contemp_nds(nds.df, eds.df, selected.nd)

Arguments

nds.df

Dataframe of the nodes as the one obtained by the function read_nds.

eds.df

Dataframe of the edges as the one obtained by the function read_eds.

selected.nd

The node of the decoration graph for which to extract the connected component. It can be either the node order (numeric) or the node name/id (character).

Value

A named list of two dataframes: list(nodes, edges), collecting the contemporaneous nodes and edges, respectivelly.

Examples

Run this code
# NOT RUN {
# Set data folder
dataDir <- system.file("extdata", package = "iconr")

# Read a decoration
nds.df <- read_nds(site = "Ibahernando",
                   decor = "Ibahernando",
                   dir = dataDir)
eds.df <- read_eds(site = "Ibahernando",
                   decor = "Ibahernando",
                   dir = dataDir)

# Extract the subgraph contemporaneous to the node 2
l_dec_df <- contemp_nds(nds.df, eds.df, selected.nd = 2)

## It returns a list of two dataframes, one for nodes and one for edges:
l_dec_df
# }

Run the code above in your browser using DataLab